==> RoboticsLanguage-0.3.8-py2-none-any.whl: RoboticsLanguage/Transformers/ROS/Language.py <==
#
#   This is the Robotics Language compiler
#
#   Language.py: Parses the Robotics Language
#
#   Created on: June 22, 2017
#       Author: Gabriel A. D. Lopes
#      Licence: Apache 2.0
#    Copyright: 2014-2017 Robot Care Systems BV, The Hague, The Netherlands. All rights reserved.
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.

from RoboticsLanguage.Base.Types import optional, arguments, returns

# from RoboticsLanguage.Base.Types import singleString, singleReal, manyStrings, manyExpressions, manyCodeBlocks, codeBlock, anything, singleBoolean
# from RoboticsLanguage.Base.Types import returnNothing, returnCodeBlock


language = {
    'RosType': {
        'definition':
        {'arguments': arguments('string'),
         'returns': returns('rosType')}
    },

    'Signals': {
        'definition': {
            'optional': {
                'rosTopic': optional('string', ''),
                'rosType': optional('string', ''),
                'rosFlow': optional('string', '')
            },
        },
    },
}

==> RoboticsLanguage-0.3.17-py2-none-any.whl: RoboticsLanguage/Transformers/ROS/Language.py <==
#
#   This is the Robotics Language compiler
#
#   Language.py: Parses the Robotics Language
#
#   Created on: June 22, 2017
#       Author: Gabriel A. D. Lopes
#      Licence: Apache 2.0
#    Copyright: 2014-2017 Robot Care Systems BV, The Hague, The Netherlands. All rights reserved.
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.

from RoboticsLanguage.Base.Types import optional, arguments, returns

# from RoboticsLanguage.Base.Types import singleString, singleReal, manyStrings, manyExpressions, manyCodeBlocks, codeBlock, anything, singleBoolean
# from RoboticsLanguage.Base.Types import returnNothing, returnCodeBlock


language = {
    'RosType': {
        'definition':
        {'arguments': arguments('string'),
         'returns': returns('rosType')}
    },

    'RosClass': {
        'definition':  {
            'arguments': arguments('none'),
            'returns': returns('rosClass'),
            'optional': {
                'class': optional('string', ''),
                'package': optional('string', ''),
                'namespace': optional('string', ''),
                'arguments': optional('set', []),
            },
        }
    },

    'Signals': {
        'definition': {
            'optional': {
                'rosTopic': optional('string', ''),
                'rosType': optional('string', ''),
                'rosFlow': optional('string', ''),
                'rosQueueSize': optional('integer', 1),
                'rosTransportHints': optional('string', '')
            },
        },
    }
}
